import React, { useEffect, useMemo, useRef } from 'react';

let marker, lineArr;
export function useMarker(amapRef, map, lujing) {
  useMemo(() => {
    if (!amapRef.current) return;
    marker = new amapRef.current.Marker({
      icon: 'https://a.amap.com/jsapi_demos/static/demo-center-v2/car.png',
      offset: new amapRef.current.Pixel(-13, -26),
    });
  }, [map]);

  useEffect(() => {
    if (!amapRef.current || !marker || !lujing || lujing.length == 0) {
      return;
    }
    lineArr = lujing;
    //https://lbs.amap.com/api/jsapi-v2/documentation#marker
    // 动态添加地图和marker的定位
    marker.setPosition(lineArr[0]);
    marker.setMap(map);
    var polyline = new amapRef.current.Polyline({
      map: map,
      path: lineArr,
      showDir: true,
      strokeColor: '#28F', //线颜色
      // strokeOpacity: 1,     //线透明度
      strokeWeight: 6, //线宽
      // strokeStyle: "solid"  //线样式
    });

    var passedPolyline = new amapRef.current.Polyline({
      map: map,
      strokeColor: '#AF5', //线颜色
      strokeWeight: 6, //线宽
    });
    //给marker添加监控
    marker.on('moving', function (e) {
      passedPolyline.setPath(e.passedPath);
      //marker运动时将marker置位地图中心
      map.setCenter(e.target.getPosition(), true);
    });
    //地图跟随marker移动
    map.setFitView();
  }, [map, lujing]);
}
export function startAnimation() {
  if (marker) {
    marker.moveAlong(lineArr, {
      // 每一段的时长
      duration: 500, //可根据实际采集时间间隔设置
      // JSAPI2.0 是否延道路自动设置角度在 moveAlong 里设置
      autoRotation: true,
    });
  }
}
export function pauseAnimation() {
  if (marker) {
    marker.pauseMove();
  }
}
export function resumeAnimation() {
  if (marker) {
    marker.resumeMove();
  }
}
export function stopAnimation() {
  if (marker) {
    marker.stopMove();
  }
}
